@@ -10,12 +10,16 @@ register = template.Library()
 
 @register.simple_tag
 def bob_icon(name, is_white=False):
+    """Display a bootstrap icon."""
+
     white = ' icon-white' if is_white else ''
     return mark_safe('<i class="icon-%s%s"></i>' % esc(name, white))
 
 
 @register.inclusion_tag('bob/main_menu.html')
 def main_menu(items, selected, title=None, search=None):
+    """Show main menu bar."""
+
     return {
         'items': items,
         'selected': selected,
@@ -25,6 +29,8 @@ def main_menu(items, selected, title=None, search=None):
 
 @register.inclusion_tag('bob/tab_menu.html')
 def tab_menu(items, selected):
+    """Show a menu in form of tabs."""
+
     return {
         'items': items,
         'selected': selected,
@@ -32,14 +38,27 @@ def tab_menu(items, selected):
 
 @register.inclusion_tag('bob/sidebar_menu.html')
 def sidebar_menu(items, selected):
+    """Show menu in a sidebar."""
+
     return {
         'items': items,
         'selected': selected,
     }
 
+@register.inclusion_tag('bob/sidebar_menu_subitems.html')
+def sidebar_menu_subitems(item, selected):
+    """Show subitems of a menu in a sidebar."""
+
+    return {
+        'item': item,
+        'selected': selected,
+    }
+
 @register.inclusion_tag('bob/pagination.html')
 def pagination(page, show_all=False, show_csv=False,
                 fugue_icons=False, url_query=None, neighbors=1):
+    """Display pagination for a list of items."""
+
     if not page:
         return {
             'show_all': show_all,
@@ -70,6 +89,8 @@ def pagination(page, show_all=False, show_csv=False,
 
 @register.filter
 def bob_page(query, page):
+    """Modify the query string of an URL to change the ``page`` argument."""
+
     if not query:
         return 'page=%s' % page
     query = query.copy()
@@ -84,6 +105,8 @@ def bob_page(query, page):
 
 @register.filter
 def bob_export(query, export):
+    """Modify the query string of an URL to change the ``export`` argument."""
+
     if not query:
         return 'export=%s' % export
     query = query.copy()
@@ -99,11 +122,14 @@ def bob_export(query, export):
 
 @register.filter
 def timesince_limited(d):
-    ''' Improved timesince '''
+    """
+    Display time between given date and now in a human-readable form if the
+    time span is less than a day, otherwise display the date normally.
+    """
     interval = datetime.datetime.now() - d
     delta = datetime.timedelta
-    if  interval < delta(days=1):
-        if  interval < delta(days=0,hours=1):
+    if interval < delta(days=1):
+        if interval < delta(days=0, hours=1):
             return timesince(d) + ' ago '
         else:
             return d.strftime('%H:%M')
